@@ -15,11 +15,10 @@ if os.name == 'nt':
     import winsound
 
 ssl._create_default_https_context = ssl._create_unverified_context
-import pandas as pd
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.31'
+__version__ = '0.1.32'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -33,7 +32,8 @@ __info__ = {
     '2022/06/13: 0.1.24 加入 tplaysound ',
     '2022/06/24: 0.1.28 加入 tLineNotify',
     '2022/06/26: 0.1.29 加入 my_addressable_IP()',
-    '2022/06/29: 0.1.30 加入需要的module'
+    '2022/06/29: 0.1.30 加入需要的module',
+    '2022/07/02: 0.1.32 加入 DefaultOrderedDict'
 }
 
 _MYPYLIB_ROOT = os.path.abspath(os.path.dirname(__file__))
@@ -44,6 +44,54 @@ request_headers = {
 
 path_cronlog = 'cronlog'
 
+from collections import OrderedDict
+from collections.abc import Callable
+
+
+class DefaultOrderedDict(OrderedDict):
+    # Source: http://stackoverflow.com/a/6190500/562769
+    def __init__(self, default_factory=None, *a, **kw):
+        if (default_factory is not None and
+                not isinstance(default_factory, Callable)):
+            raise TypeError('first argument must be callable')
+        OrderedDict.__init__(self, *a, **kw)
+        self.default_factory = default_factory
+
+    def __getitem__(self, key):
+        try:
+            return OrderedDict.__getitem__(self, key)
+        except KeyError:
+            return self.__missing__(key)
+
+    def __missing__(self, key):
+        if self.default_factory is None:
+            raise KeyError(key)
+        self[key] = value = self.default_factory()
+        return value
+
+    def __reduce__(self):
+        if self.default_factory is None:
+            args = tuple()
+        else:
+            args = self.default_factory,
+        return type(self), args, None, None, self.items()
+
+    def copy(self):
+        return self.__copy__()
+
+    def __copy__(self):
+        return type(self)(self.default_factory, self)
+
+    def __deepcopy__(self, memo):
+        import copy
+        return type(self)(self.default_factory,
+                          copy.deepcopy(self.items()))
+
+    def __repr__(self):
+        return 'OrderedDefaultDict(%s, %s)' % (self.default_factory,
+                                               OrderedDict.__repr__(self))
+
+
 import urllib.request
 
 
@@ -92,6 +140,7 @@ def get_all_stock_code_name_dict():
 
 
 def get_day_trade_candidates(output_file_path='可當沖.json', days=0):
+    import pandas as pd
     OTC_url_format = 'https://www.tpex.org.tw/web/stock/trading/' \
                      'intraday_trading/intraday_trading_list_print.php?' \
                      'l=zh-tw&d={}/{:02d}/{:02d}&stock_code=&s=0,asc,1'
@@ -205,6 +254,7 @@ def get_stock_future_snapshot(filename='stock_future_snapshot.txt'):
 
 
 def get_stock_future_data(filename='stock_future_data.txt'):
+    import pandas as pd
     if not os.path.isdir(path_cronlog):
         os.mkdir(path_cronlog)
 
@@ -222,6 +272,7 @@ def get_stock_future_data(filename='stock_future_data.txt'):
 
 
 def get_punishment_list():
+    import pandas as pd
     if not os.path.isdir(path_cronlog):
         os.mkdir(path_cronlog)
 
@@ -462,6 +513,7 @@ def mypylib_unit_test():
 
 
 def short_selling_to_csv():
+    import pandas as pd
     for day in date_range(datetime.datetime(year=2019, month=1, day=1), datetime.datetime.today()):
         print(day)
         TSE_path_cache = f'{path_cronlog}/TSE-short-selling_list-{day.strftime("%Y-%m-%d")}.txt'
